View source: R/example_functions.R
| fut.arm.simple | R Documentation |
allows stopping an arm for futility when the probability of the corresponding target parameter being greater or smaller (depending on the argument 'alternative' of batss.glm) than 'delta.fut' is smaller than a fixed value 'b'
fut.arm.simple(posterior, b)
posterior |
the 'BATSS' ingredient ' |
b |
the cut-off value used to declare futility (to be defined in |
fut.arm.simple returns a logical constant.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.