| plot.batss | R Documentation |
Plot for objects of class 'batss'
## S3 method for class 'batss'
plot(
x,
which = 1:4,
ask = TRUE,
hypothesis = "H1",
title = TRUE,
legend = TRUE,
ess = TRUE,
percentage = TRUE,
beta = TRUE,
col = c("#008B0040", "#8B3A3A40", "#8B897040", "#FF990075"),
smooth = 1,
...
)
x |
An object of class 'batss' (i.e., output of the function batss.glm). |
which |
An integer vector indicating the list of desired plots. If a subset of the plots is required, specify a subset of the numbers |
ask |
A logical. If |
hypothesis |
A character string indicating which alternative hypothesis to use for analyses considering both "H0" and "H1", with options "H1" (default) and "H0". |
title |
Either a logical indicating if a title should be added or a string (of class character) indicating the title to be added. If |
legend |
A logical (with default set to |
ess |
A logical (with default set to |
percentage |
A logical (with default set to |
beta |
A logical (with default set to |
col |
A vector of length 4 specifying the colours to be used. Default to |
smooth |
A numerical (>0) indictating the level of smoothing of the violin plots (for plot |
... |
Additional arguments affecting the plot produced, like ylim and ylab. |
Generates graphical displays of results for objects of class 'batss'.
batss.glm(), the function generating S3 objects of class 'batss'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.